@@ -17,36 +17,34 @@
 #' @seealso Makes an `UpdateSheetPropertiesRequest`:
 #'   * <# https://developers.google.com/sheets/api/reference/rest/v4/spreadsheets/request#UpdateSheetPropertiesRequest>
 #'
-#' @examples
-#' if (gs4_has_token()) {
-#'   # create a Sheet with the default initial worksheet
-#'   (ss <- gs4_create("sheet-resize-demo"))
+#' @examplesIf gs4_has_token()
+#' # create a Sheet with the default initial worksheet
+#' (ss <- gs4_create("sheet-resize-demo"))
 #'
-#'   # see (work)sheet dims
-#'   sheet_properties(ss)
+#' # see (work)sheet dims
+#' sheet_properties(ss)
 #'
-#'   # no resize occurs
-#'   sheet_resize(ss, nrow = 2, ncol = 6)
+#' # no resize occurs
+#' sheet_resize(ss, nrow = 2, ncol = 6)
 #'
-#'   # reduce sheet size
-#'   sheet_resize(ss, nrow = 5, ncol = 7, exact = TRUE)
+#' # reduce sheet size
+#' sheet_resize(ss, nrow = 5, ncol = 7, exact = TRUE)
 #'
-#'   # add rows
-#'   sheet_resize(ss, nrow = 7)
+#' # add rows
+#' sheet_resize(ss, nrow = 7)
 #'
-#'   # add columns
-#'   sheet_resize(ss, ncol = 10)
+#' # add columns
+#' sheet_resize(ss, ncol = 10)
 #'
-#'   # add rows and columns
-#'   sheet_resize(ss, nrow = 9, ncol = 12)
+#' # add rows and columns
+#' sheet_resize(ss, nrow = 9, ncol = 12)
 #'
-#'   # re-inspect (work)sheet dims
-#'   sheet_properties(ss)
+#' # re-inspect (work)sheet dims
+#' sheet_properties(ss)
 #'
-#'   # clean up
-#'   gs4_find("sheet-resize-demo") %>%
-#'     googledrive::drive_trash()
-#' }
+#' # clean up
+#' gs4_find("sheet-resize-demo") %>%
+#'   googledrive::drive_trash()
 sheet_resize <- function(ss,
                          sheet = NULL,
                          nrow = NULL, ncol = NULL,
@@ -59,12 +57,14 @@ sheet_resize <- function(ss,
 
   x <- gs4_get(ssid)
   s <- lookup_sheet(sheet, sheets_df = x$sheets)
-  message_glue("Resizing sheet {dq(s$name)} in {dq(x$name)}")
+  gs4_bullets(c(v = "Resizing sheet {.w_sheet {s$name}} in {.s_sheet {x$name}}."))
 
   bureq <- prepare_resize_request(s, nrow_needed = nrow, ncol_needed = ncol, exact = exact)
 
   if (is.null(bureq)) {
-    message_glue("No need to change existing dims ({s$grid_rows} x {s$grid_columns})")
+    gs4_bullets(c(
+      i = "No need to change existing dims ({s$grid_rows} x {s$grid_columns})."
+    ))
     return(invisible(ssid))
   }
 
@@ -72,9 +72,10 @@ sheet_resize <- function(ss,
   new_nrow <- pluck(new_grid_properties, "rowCount") %||% s$grid_rows
   new_ncol <- pluck(new_grid_properties, "columnCount") %||% s$grid_columns
 
-  message_glue(
-    "Changing dims: ({s$grid_rows} x {s$grid_columns}) --> ({new_nrow} x {new_ncol})"
-  )
+  gs4_bullets(c(
+    v = "Changing dims: ({s$grid_rows} x {s$grid_columns}) --> \\
+         ({new_nrow} x {new_ncol})."
+  ))
 
   req <- request_generate(
     "sheets.spreadsheets.batchUpdate",
